Details
-
Bug
-
Status: Open (View Workflow)
-
Major
-
Resolution: Unresolved
-
13.2
-
Related to performance
Description
Union query execution time increases from 10ms to 18ms in Parallel mode of 100.
Note:
Perf improvement seen with less worker threads (2,4,8,16,32)
Query:
analyze ( SELECT t1.col_int_key, COUNT(*), SUM( t1.col_int ) FROM G t1 WHERE NOT t1.col_int > 1 GROUP BY t1.col_int_key ) UNION ( SELECT t1.col_int_key, COUNT(*), SUM( t1.col_int ) FROM C t1 GROUP BY t1.col_int_key ) ; |
Serial : 0.010sec (10ms)
Parallel (100 worker threads ): 0.018sec (18ms)
For analyze output refer:
serial : analyze-json.txt
Parallel : analyze-json-PQ.txt
Version details:
----------------------
Branch: bb-13.2-MDEV-40012-refactored-input3
Commit:1648b516083ccdbddeb123dc6cf2c2f62d7b0328
Version:13.1.0
How to repro:
source tables.sql;
|
 |
//Run query with 0 and 100 threads and note the difference |
SET parallel_worker_threads=0; |
analyze ( SELECT t1.col_int_key, COUNT(*), SUM( t1.col_int ) FROM G t1 WHERE NOT t1.col_int > 1 GROUP BY t1.col_int_key ) UNION ( SELECT t1.col_int_key, COUNT(*), SUM( t1.col_int ) FROM C t1 GROUP BY t1.col_int_key ) ; |
Attachments
Issue Links
- is caused by
-
MDEV-40012 Parallel Query: execute the join in the worker threads
-
- In Progress
-